pub struct TablistConfig {
pub enabled: bool,
pub header: String,
pub footer: String,
}Expand description
Configuration for the tablist mechanics module.
Fields
enabled: boolWhether this module is active.
header: StringHeader text displayed at the top of the tab list. Supports Minecraft formatting codes. Leave empty to disable.
Footer text displayed at the bottom of the tab list. Supports Minecraft formatting codes. Leave empty to disable.